@@ -11,10 +11,7 @@ seed_everything(234)
 
 
 def main(args):
-    """
-    Main training routine specific for this project
-    :param hparams:
-    """
+    """ Main training routine specific for this project. """
     # ------------------------
     # 1 INIT LIGHTNING MODEL
     # ------------------------
@@ -36,13 +33,13 @@ def run_cli():
     # TRAINING ARGUMENTS
     # ------------------------
     # these are project-wide arguments
-
     root_dir = os.path.dirname(os.path.realpath(__file__))
     parent_parser = ArgumentParser(add_help=False)
 
     # each LightningModule defines arguments relevant to it
     parser = LightningTemplateModel.add_model_specific_args(parent_parser, root_dir)
     parser = Trainer.add_argparse_args(parser)
+    parser.set_defaults(gpus=2)
     args = parser.parse_args()
 
     # ---------------------
