@@ -4,31 +4,28 @@ Multi-node example (GPU)
 import os
 from argparse import ArgumentParser
 
-import numpy as np
-import torch
-
-import pytorch_lightning as pl
+from pytorch_lightning import Trainer, seed_everything
 from pl_examples.models.lightning_template import LightningTemplateModel
 
-SEED = 2334
-torch.manual_seed(SEED)
-np.random.seed(SEED)
+seed_everything(234)
 
 
-def main(hparams):
+def main(args):
     """Main training routine specific for this project."""
     # ------------------------
     # 1 INIT LIGHTNING MODEL
     # ------------------------
-    model = LightningTemplateModel(hparams)
+    model = LightningTemplateModel(args)
 
     # ------------------------
     # 2 INIT TRAINER
     # ------------------------
-    trainer = pl.Trainer(
-        gpus=2,
-        num_nodes=2,
-        distributed_backend='ddp2'
+    trainer = Trainer(
+        gpus=args.gpus,
+        num_nodes=args.num_nodes,
+        distributed_backend='ddp2',
+        max_epochs=args.max_epochs,
+        max_steps=args.max_steps,
     )
 
     # ------------------------
@@ -37,15 +34,20 @@ def main(hparams):
     trainer.fit(model)
 
 
-if __name__ == '__main__':
+def run_cli():
     root_dir = os.path.dirname(os.path.realpath(__file__))
     parent_parser = ArgumentParser(add_help=False)
 
     # each LightningModule defines arguments relevant to it
     parser = LightningTemplateModel.add_model_specific_args(parent_parser, root_dir)
-    hyperparams = parser.parse_args()
+    parser = Trainer.add_argparse_args(parser)
+    args = parser.parse_args()
 
     # ---------------------
     # RUN TRAINING
     # ---------------------
-    main(hyperparams)
+    main(args)
+
+
+if __name__ == '__main__':
+    run_cli()
