@@ -31,6 +31,7 @@ class LightningTemplateModel(LightningModule):
         ...     optimizer_name='adam',
         ...     data_root='./datasets',
         ...     out_features=10,
+        ...     num_workers=4,
         ...     hidden_dim=1000,
         ... )
         >>> model = LightningTemplateModel(**params)
@@ -44,11 +45,14 @@ class LightningTemplateModel(LightningModule):
                  optimizer_name: str = 'adam',
                  data_root: str = './datasets',
                  out_features: int = 10,
+                 num_workers: int = 4,
                  hidden_dim: int = 1000,
                  **kwargs
                  ):
         # init superclass
         super().__init__()
+
+        self.num_workers = num_workers
         self.drop_prob = drop_prob
         self.batch_size = batch_size
         self.in_features = in_features
@@ -150,13 +154,13 @@ class LightningTemplateModel(LightningModule):
         self.mnist_test = MNIST(self.data_root, train=False, download=False, transform=transform)
 
     def train_dataloader(self):
-        return DataLoader(self.mnist_train, batch_size=self.batch_size, num_workers=4)
+        return DataLoader(self.mnist_train, batch_size=self.batch_size, num_workers=self.num_workers)
 
     def val_dataloader(self):
-        return DataLoader(self.mnist_test, batch_size=self.batch_size, num_workers=4)
+        return DataLoader(self.mnist_test, batch_size=self.batch_size, num_workers=self.num_workers)
 
     def test_dataloader(self):
-        return DataLoader(self.mnist_test, batch_size=self.batch_size, num_workers=4)
+        return DataLoader(self.mnist_test, batch_size=self.batch_size, num_workers=self.num_workers)
 
     @staticmethod
     def add_model_specific_args(parent_parser, root_dir):  # pragma: no-cover
@@ -175,6 +179,7 @@ class LightningTemplateModel(LightningModule):
         parser.add_argument('--hidden_dim', default=50000, type=int)
         parser.add_argument('--drop_prob', default=0.2, type=float)
         parser.add_argument('--learning_rate', default=0.001, type=float)
+        parser.add_argument('--num_workers', default=4, type=int)
 
         # data
         parser.add_argument('--data_root', default=os.path.join(root_dir, 'mnist'), type=str)
