@@ -46,10 +46,3 @@ except ImportError:  # pragma: no-cover
     pass  # pragma: no-cover
 else:
     __all__.append('WandbLogger')
-
-try:
-    from pytorch_lightning.loggers.trains import TrainsLogger
-except ImportError:  # pragma: no-cover
-    pass  # pragma: no-cover
-else:
-    __all__.append('TrainsLogger')
