@@ -6,8 +6,9 @@ from pytorch_lightning.core.lightning import LightningModule
 
 class TrainerModelHooksMixin(ABC):
 
-    def is_function_implemented(self, f_name):
-        model = self.get_model()
+    def is_function_implemented(self, f_name, model=None):
+        if model is None:
+            model = self.get_model()
         f_op = getattr(model, f_name, None)
         return callable(f_op)
 
@@ -41,5 +42,5 @@ class TrainerModelHooksMixin(ABC):
         return arg_name in inspect.signature(f_op).parameters
 
     @abstractmethod
-    def get_model(self):
+    def get_model(self) -> LightningModule:
         """Warning: this is just empty shell for code implemented in other class."""
